unsigned long resolv_address(char* address);

void connect_fail(socket_t* socket, char* text);
void connect_progress(char* text);
void connect_success();

socket_t* socket_new(int type);
void socket_destroy(socket_t* socket, void* data);
void socket_end(socket_t* socket, void* data);
char* socket_get_name(socket_t* socket);

int napster_check(gpointer data);
void napster_reset();
int napster_connect(server_t* server);
void napster_disconnect(char* message);
int get_best_server(socket_t* socket);

int send_command(gint16 type, char* data);
char* receive_command(socket_t* socket, gint16 *code);

void create_upload_port(int port, int send);
int connect_socket(socket_t* s, char* proto, int type);

void socket_update_clist(socket_t* socket);
void socket_show_clist(socket_t* socket);
void socket_remove_clist(socket_t* socket);
